==> koshoten.net-2.2.1.tar.gz: koshoten-net/catalog/information.php <==
<?php
/*
  information.php
  2004/12/2
ǽ2005/6/1

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

  require('includes/application_top.php');

  $shop_info_query = tep_db_query("select shop_info_id, shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_id = '" . (int)$HTTP_GET_VARS['siID'] . "' and shop_info_type = '1'");
  if (tep_db_num_rows($shop_info_query)) {
    $shop_info = tep_db_fetch_array($shop_info_query);
    $breadcrumb->add($shop_info['shop_info_title'], tep_href_link(FILENAME_INFORMATION, 'siID=' . $shop_info['shop_info_id']));
    if ($shop_info['allow_tags']) {
      $shop_info_value = $shop_info['shop_info_value'];
    } else {
      $shop_info_value = nl2br(htmlspecialchars($shop_info['shop_info_value']));
    }
  } else {
    tep_redirect(tep_href_link(FILENAME_DEFAULT));
  }
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_INFORMATION, 0, strrpos(FILENAME_INFORMATION, '.'));?>.css" media="screen,print" />
</head>
<body>
<div id="container">
<!-- header -->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- /header -->
<hr />
<!-- contents -->
<div id="contents">
<!-- left_contents -->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- /left_contents -->
<hr />
<!-- right_contents -->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- /right_contents -->
<hr />
<!-- main_contents -->
<div id="mainContents">
<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
<h2 class="pageHeading"><?php echo $shop_info['shop_info_title']; ?></h2>
<div id="shopInfo">
<p><?php echo $shop_info_value; ?></p>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_DEFAULT) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
</div>
<!-- /main_contents -->
</div>
<!-- /contents -->
<hr />
<!-- footer -->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- /footer -->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>

==> koshoten.net-2.2.2.tar.gz: koshoten-net/catalog/information.php <==
<?php
/*
  information.php
  2004/12/2
ǽ2005/6/1

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

  require('includes/application_top.php');

  $shop_info_query = tep_db_query("select shop_info_id, shop_info_title, shop_info_value, allow_tags from " . TABLE_SHOP_INFO . " where shop_info_id = '" . (int)$HTTP_GET_VARS['siID'] . "' and shop_info_type = '1'");
  if (tep_db_num_rows($shop_info_query)) {
    $shop_info = tep_db_fetch_array($shop_info_query);
    $breadcrumb->add($shop_info['shop_info_title'], tep_href_link(FILENAME_INFORMATION, 'siID=' . $shop_info['shop_info_id']));
    if ($shop_info['allow_tags']) {
      $shop_info_value = $shop_info['shop_info_value'];
    } else {
      $shop_info_value = nl2br(htmlspecialchars($shop_info['shop_info_value']));
    }
  } else {
    tep_redirect(tep_href_link(FILENAME_DEFAULT));
  }
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<?php 
  $customCSS = substr(FILENAME_INFORMATION, 0, strrpos(FILENAME_INFORMATION, '.')). ".css";
  if (file_exists($customCSS)){
    echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"$customCSS\" media=\"screen,print\" />";
  }
?>
</head>
<body>
<div id="container">
<!-- header -->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- /header -->
<hr />
<!-- contents -->
<div id="contents">
<!-- left_contents -->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- /left_contents -->
<hr />
<!-- right_contents -->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- /right_contents -->
<hr />
<!-- main_contents -->
<div id="mainContents">
<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
<h2 class="pageHeading"><?php echo $shop_info['shop_info_title']; ?></h2>
<div id="shopInfo">
<p><?php echo $shop_info_value; ?></p>
<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_DEFAULT) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
</div>
</div>
</div>
<!-- /main_contents -->
</div>
<!-- /contents -->
<hr />
<!-- footer -->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- /footer -->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
